import * as React from 'react';
import PropTypes from 'prop-types';
import Tabs from '@mui/material/Tabs';
import Tab from '@mui/material/Tab';
import Typography from '@mui/material/Typography';
import Box from '@mui/material/Box';

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}      
      id={`vertical-tabpanel-${index}`}
      aria-labelledby={`vertical-tab-${index}`}      
      {...other}
    >
      {value === index && (
        <Box sx={{ pl: 3 }}>
          <Typography variant="h6" style={{marginBottom:20, color:'#22436E', fontWeight:'bold'}}>{children}</Typography>
          <Box>  
            <div dangerouslySetInnerHTML={{ __html: props.details }} />
          </Box>

        </Box>
      )}
    </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.number.isRequired,
  value: PropTypes.number.isRequired,
};

function a11yProps(index) {
  return {
    id: `vertical-tab-${index}`,
    'aria-controls': `vertical-tabpanel-${index}`,
  };
}

export default function VerticalTabs(props) {
  const [value, setValue] = React.useState(0);

  const handleChange = (event, newValue) => {
    setValue(newValue);
  };

  return (
    <Box
      sx={{ flexGrow: 1, bgcolor: '#eff3f6', display: 'flex', minHeight: 700, marginLeft: 5, marginTop: 6, marginBottom: 10 }}
    >
      
      <Tabs
        orientation="horizontal"
        variant="scrollable"
        value={value}
        onChange={handleChange}
        aria-label="Vertical tabs example"
        //sx={{ borderRight: 1, borderColor: 'divider', minWidth:200}}
        //TabIndicatorProps={{style: {background:'#ffd25d'}}}
        centered={false}
      >
        {
          props.tabs?props.tabs.map((myObj,index)=>(
            <Tab label={myObj.heading} {...a11yProps(index)} />
          )):null
        }
      </Tabs>
        {
          props.tabs?props.tabs.map((myObj,index)=>(
            <TabPanel details={myObj.details} value={value} index={index} >
              {myObj.heading}
            </TabPanel>
          )):null
        }
          
    </Box>
  );
}
