import React from 'react';
import PropTypes from 'prop-types';
import { makeStyles } from '@material-ui/core/styles';
import { AppBar, Tabs, Tab, Box, Link} from '@material-ui/core';

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
        <div
          role="tabpanel"
          hidden={value !== index}
          id={`scrollable-auto-tabpanel-${index}`}
          aria-labelledby={`scrollable-auto-tab-${index}`}
          {...other}
        >
          {value === index && (
            <Box mt={2}>
              <h4 style={{textAlign:'center'}} >{children}</h4>
            </Box>
          )}
        </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired,
};

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    width: '100%',
  },
}));

export default function ScrollableTabsButtonAuto(props) {
  const classes = useStyles();

  return (
    <div className={classes.root}>
      <AppBar position="static" style={{backgroundColor: '#eff3f6',boxShadow:'none',boxSizing:'none',maxWidth: '100vw'}} > 
        <Tabs
          indicatorColor="primary"
          textColor="primary"
          variant="scrollable"
          scrollButtons="auto"
          aria-label="scrollable"
          style={{alignSelf:'center',maxWidth:'100vw'}}
        >
          {props.courses?props.courses.map((myObj)=>(  
              <Tab key={myObj.courseTitle} onClick={()=>{window.location='/course/'+myObj.courseUrl}} className='courseTab' label={
                      <div className="sellerbox">
                        <h5 style={{fontSize: '1rem', whiteSpace: 'nowrap',overflow: 'hidden'}} >{myObj.categoryName}</h5>
                        <h4 style={{fontSize:'1.3rem', whiteSpace: 'nowrap',overflow: 'hidden'}} >{myObj.courseTitle}</h4>
                        <img loading="lazy" alt="map icon ETL" src="/map.webp" width="100%" />
                        <a href={'/course/'+myObj.courseUrl} className="btn sellerbt ">view details</a>
                      </div>
                  }
              />
          )):null}    

        </Tabs>
      </AppBar>

    </div>

  );
}
