import React from "react";
import Head from "next/head";
import { useSelector } from "react-redux";

// MUI
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid } from "@material-ui/core";

// Components
import Header from "../../components/Header";
import Footer from "../../components/Footer";

// CSS
import styles from "./AboutUs.module.css";

const useStyles = makeStyles((theme) => ({
  root: {
    background: "linear-gradient(45deg, #33ccff 30%, #0000ff 90%)",
    border: 0,
    borderRadius: 22,
    boxShadow: "0 3px 5px 2px rgba(255, 105, 135, .3)",
    color: "white",
    height: 48,
    padding: "0 30px",
    marginTop: "30px",
  },
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "flex",
    },
  },
  sectionMobile: {
    display: "flex",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const cityListing = useSelector((state) => state.cityListing);
  const myCity = cityListing
    .map((city) => city.name)
    .toString()
    .toLowerCase();
  const [selectedCity, setCity] = React.useState("delhi");
  const classes = useStyles();

  React.useEffect(() => {
    setCity(myCity);
  });

  return (
    <>
      <Head>
        <title>
          About us | India`s Largest Free Learning Platform | EaseToLearn
        </title>
        <meta
          name="description"
          content="Online Exam Preparation Site -Engine To Accelerate your Learning | EaseToLearn"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />
        <div className={styles.about_us_background}>
          <h1 className={styles.about_us_heading}>
            <span className={styles.about_us_we_are}>WE ARE HERE</span>{" "}
            <span className={styles.about_us_to}>to</span>{" "}
            <span className={styles.about_us_revolutionize}>
              REVOLUTIONALIZE
            </span>{" "}
            <span className={styles.about_way}>the way</span>{" "}
            <span className={styles.about_us_learn}>YOU LEARN</span>
          </h1>
        </div>
        <div className="mybody" style={{ marginTop: 30 }}>
          <section className="mycontainer ">
            <div className="barbox-head color-dark">
              <h2 className="fixhead">Who are we?</h2>
              <div className="bar bg-dark"></div>
            </div>
          </section>

          <Box className="aboutUsBox">
            <Grid container>
              <Grid item md={6} sm={6} xs={12}>
                <p className={styles.aboutUs_para}>
                  We are an e-learning platform, run by a team of innovative and
                  dedicated minds, who are motivated by their need to improve
                  the lives of students. We are a team of believers, who are
                  ardently working and building an environment where a student
                  succeeds, freely and remarkably.
                </p>
              </Grid>
              <Grid item md={6} sm={6} xs={12} style={{ textAlign: "center" }}>
                <img
                  loading="lazy"
                  alt="ease to learn logo"
                  src="/logo-one.webp"
                  style={{ height: 150 }}
                />
              </Grid>
            </Grid>
          </Box>

          <section className="mycontainer " style={{ marginTop: 20 }}>
            <div className="barbox-head color-dark">
              <h2 className="fixhead">What do we stand for?</h2>
              <div className="bar bg-dark"></div>
            </div>
          </section>

          <Box className="aboutUsBox">
            <Grid container>
              <Grid item md={6} sm={6} xs={12} style={{ textAlign: "center" }}>
                <img
                  loading="lazy"
                  alt="people working to a common goal ETL"
                  src="/group81.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <p className={`${styles.aboutUs_para} ${styles.aboutUs_center}`}>
                  We as humans harbour a multitude of capacities. Being forced
                  to learn linearly is only an inhibition of our talents. We, at
                  EaseToLearn aim to create an infrastructure of learning that
                  will enable intensive comprehension without it being a burden.
                  Through our services of MY Study Room and MY Exam Room, we
                  strive toward reshaping the entire learning culture.
                </p>
              </Grid>
            </Grid>
          </Box>

          <div className="margin-bottommin-res"></div>
        </div>

        <Footer />
      </main>
    </>
  );
}
