import React, { useEffect, useState } from "react";
import axios from "axios";
import Head from "next/head";
import Cookies from "js-cookie";
import { useRouter } from "next/router";

// Mui Components
import CircularProgress from "@mui/material/CircularProgress";
import { Box } from "@material-ui/core";

// Components
import Header from "../components/Header";
import Footer from "../components/Footer";

export default function Home() {
  const accountDetails = Cookies.get("accountDetails");
  const courseDetails = Cookies.get("courseDetails");
  const joinFree = Cookies.get("header_join_for_free");
  const [apiErrorMsg, setApiErrorMsg] = useState("");
  var redirectTime = 4000;

  const router = useRouter();
  var { user } = router.query;
  if (user === "new") {
    redirectTime = 12000;
  }

  useEffect(() => {
    if (!courseDetails) {
      window.location.href = "/courses";
    } else if (!accountDetails) {
      if (courseDetails) {
        const objCourse = JSON.parse(courseDetails);
        if (objCourse.subscriptionType === "Paid") {
          window.location.href = "/login";
        } else {
          window.location.href = "/create-account";
        }
      } else {
        window.location.href = "/create-account";
      }
    } else if (accountDetails && courseDetails) {
      submit(accountDetails, courseDetails);
    }
  }, [accountDetails, courseDetails]);

  function submit(accountDetails, courseDetails) {
    if (accountDetails && courseDetails) {
      const objAccount = JSON.parse(accountDetails);
      const objCourse = JSON.parse(courseDetails);
      const objHeaderFree = JSON.parse(
        joinFree ? joinFree : JSON.stringify({})
      );

      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      let apiUrl = "/newstudentregistration";
      if (objAccount && objAccount.token && objAccount.token.length > 0) {
        data.append("token", objAccount.token);
        apiUrl = "/mobile-addcousetomyaccount";
      } else if (
        objAccount &&
        objAccount.mobile &&
        objAccount.mobile.length > 0
      ) {
        data.append("studentName", objAccount.studentName);
        data.append("mobile", objAccount.mobile);
        if (objAccount.email && objAccount.email.length > 3) {
          data.append("email", objAccount.email);
        }
        data.append("newPassword", objAccount.newPassword);
      }

      data.append("courseId", objCourse.courseId);
      data.append("regDevice", "Desktop");

      axios
        .post(process.env.NEXT_PUBLIC_API_URL + apiUrl, data, axiosHeader)
        .then((response) => {
          if (objHeaderFree) {
            setTimeout(() => {
              Cookies.remove("header_join_for_free");
              window.location.href =
                process.env.NEXT_PUBLIC_LOGIN_URL +
                "/logindirect?loginKey=" +
                response.data.token;
            }, 4000);
          }

          if (
            objCourse.subscriptionType === "Paid" &&
            response.data.responseTxt === "OK"
          ) {
            let accountObj = {
              token: response.data.token,
              studentId: response.data.studentId,
              studentName: objAccount.studentName,
              email: objAccount.email,
              mobile: objAccount.mobile,
            };
            getPaidCourse(accountObj, objCourse);
            return false;
          } else if (response.data.responseTxt === "OK") {
            const mytimeoutVarr = setTimeout(
              redirectingToAccount,
              redirectTime
            );
            function redirectingToAccount() {
              window.location.href =
                process.env.NEXT_PUBLIC_LOGIN_URL +
                "/logindirect?loginKey=" +
                response.data.token;
              clearTimeout(mytimeoutVarr);
            }
            return false;
          } else {
            Cookies.remove("accountDetails");
            Cookies.remove("courseDetails");
            Cookies.remove("resetPasswordToken");
            window.location.href = "/courses";
            return false;
          }
        })
        .catch((error) => {
          setApiErrorMsg("" + error);
          return false;
        });
    }
  }

  function getPaidCourse(objAccount, objCourse) {
    if (objAccount && objCourse) {
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
          studentId: objAccount.studentId,
          token: objAccount.token,
        },
      };

      const data = new FormData();
      data.append("token", objAccount.token);
      data.append("courseId", objCourse.courseId);

      let apiQuery = "&webUrl=" + process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES;
      if (objCourse && objCourse.promoCode && objCourse.promoCode.length > 0) {
        apiQuery += "&promoCode=" + objCourse.promoCode;
      }

      axios
        .get(
          process.env.NEXT_PUBLIC_API_URL +
            "/paymenttokengenerate-multiple-pricing?studentName=" +
            objAccount.studentName +
            "&email=" +
            objAccount.email +
            "&phone=" +
            objAccount.mobile +
            "&courseId=" +
            objCourse.courseId +
            "&courseName=" +
            objCourse.courseName +
            "&packId=" +
            objCourse.packId +
            apiQuery,
          axiosHeader
        )
        .then((response) => {
          if (response.data.responseTxt === "success") {
            if (response.data.amount > 0) {
              document.pgform.key.value = response.data.key;
              document.pgform.txnid.value = response.data.token;
              document.pgform.amount.value = response.data.amount;
              document.pgform.firstname.value = objAccount.studentName;
              document.pgform.email.value = objAccount.email;
              document.pgform.phone.value = objAccount.mobile;
              document.pgform.productinfo.value = response.data.productinfo;
              document.pgform.surl.value =
                process.env.NEXT_PUBLIC_PAYMENT_GATEWAY_SUCCESS_URL;
              document.pgform.furl.value =
                "https://" + process.env.NEXT_PUBLIC_WEB_URL + "/pgcancelled";
              document.pgform.hash.value = response.data.hashCode;
              document.pgform.submit();
            } else {
              window.location.href =
                process.env.NEXT_PUBLIC_LOGIN_URL +
                "/logindirect?loginKey=" +
                response.data.token;
              return false;
            }
          } else {
            setApiErrorMsg(
              "Seems like you have already signed up with us. You can subscribe to any course from your account. Redirecting you to your account in few seconds. Have a good day!"
            );

            const mytimeoutVar = setTimeout(redirectingToAccount, redirectTime);
            function redirectingToAccount() {
              window.open(
                "https://easetolearn.com/student/selectcourse",
                "_blank"
              );
              clearTimeout(mytimeoutVar);
            }

            return false;
          }
        })
        .catch((error) => {
          setApiErrorMsg("" + error);
          return false;
        });
    }
  }

  return (
    <>
      <Head>
        <title>Creating your account</title>
        <meta name="description" content="Creating your account" />
        <meta name="keywords" content="Creating your account" />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box mt={5} style={{ textAlign: "center" }}>
            {apiErrorMsg ? (
              <>{apiErrorMsg}</>
            ) : (
              <>
                <CircularProgress />
                <br />
                <span style={{ fontSize: 30, color: "#c51162" }}>Wait...</span>
                <br />
                {/* <span style={{fontSize:14,color:'#0000FF',fontWeight:'bold'}} >It is creating your account and setting up your courses</span> */}
                <br />
                <span style={{ fontWeight: "bold" }}>
                  Please do not close this window.
                </span>
              </>
            )}
          </Box>

          <form
            name="pgform"
            action="https://secure.payu.in/_payment"
            method="post"
          >
            <input type="hidden" name="key" value="" />
            <input type="hidden" name="txnid" value="" />
            <input type="hidden" name="amount" value="" />
            <input type="hidden" name="productinfo" value="" />
            <input type="hidden" name="firstname" value="" />
            <input type="hidden" name="email" value="" />
            <input type="hidden" name="phone" value="" />
            <input type="hidden" name="surl" value="" />
            <input type="hidden" name="furl" value="" />
            <input type="hidden" name="hash" value="" />
          </form>
        </Box>

        <Footer />
      </main>
    </>
  );
}