import React, { useEffect, useState, useRef } from "react";
import Head from "next/head";
import axios from "axios";
///import FormControlLabel from '@mui/material/FormControlLabel';
import CircularProgress from "@mui/material/CircularProgress";
///import Checkbox from '@mui/material/Checkbox';
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import Header from "../components/Header";
import Footer from "../components/Footer";
import FormHelperText from "@mui/material/FormHelperText";
import Cookies from "js-cookie";
import LoginPop from "../components/LoginPop";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const classes = useStyles();

  const [waitBtn, setWaitBtn] = useState(false);
  const [waitPassBtn, setWaitPassBtn] = useState(false);
  const [userId, setUserId] = useState("");
  const [password, setPassword] = useState("");

  const [mobileVal, setMobileVal] = useState(false);
  const [mobileValMsg, setMobileValMsg] = useState(
    "Enter your User Id or Email Id or Mobile Number"
  );

  const [newPasswordMsg, setNewPasswordMsg] = useState("");

  const childRefLoginPop = useRef();

  //   function goLoginPop() {
  //     childRefLoginPop.current.handleClickOpen();
  //   }

  useEffect(() => {
    const urlParams = new URLSearchParams(location.search);
    if (urlParams.has("mobile")) {
      setUserId(urlParams.get("mobile"));
    }
  }, []);

  useEffect(() => {
    if (newaccount) {
      const obj = JSON.parse(newaccount);
      setUserId(obj.mobile);
    }
  }, [newaccount]);

  function submit() {
    if (!userId || userId.trim().length < 1) {
      if (userId) {
        setUserId(userId.trim());
      }
      setMobileVal(true);
      return false;
    } else {
      setMobileVal(false);
    }
    if (!password) {
      setNewPasswordMsg("Enter your password");
      return false;
    } else {
      setNewPasswordMsg("");
    }

    if (userId && password) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("userId", userId);
      data.append("password", password);

      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/loginmultiorg",
          data,
          axiosHeader
        )
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 1000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "OK") {
            // Cookies.set('newaccount', JSON.stringify({firstName:firstName, lastName:lastName, mobile:userId, token:response.data.token, utype:utype}));
            Cookies.set(
              "accountDetails",
              JSON.stringify({ token: response.data.loginKey })
            );
            window.location.href = "/create-account-process";
            return false;
          } else {
            setMobileVal(true);
            setMobileValMsg("Your user-id or password is invalid.");
            return false;
          }
        })
        .catch((error) => {
          setMobileVal(true);
          setMobileValMsg("" + error);
          return false;
        });
    }
  }

  function forgotPassword() {
    if (!userId || userId.trim().length < 1) {
      if (userId) {
        setUserId(userId.trim());
      }
      setMobileVal(true);
      return false;
    } else {
      setMobileVal(false);
    }

    if (userId) {
      setWaitPassBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("userId", userId);

      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/sendresetpasswordkey",
          data,
          axiosHeader
        )
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 1000);
          function myWaitBtnStop() {
            setWaitPassBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "OK") {
            ///alert(JSON.stringify(response.data));
            Cookies.set("resetPasswordToken", JSON.stringify(response.data));
            Cookies.remove("newaccount");
            Cookies.remove("accountDetails");
            //Cookies.set('newaccount', JSON.stringify({firstName:firstName, lastName:lastName, mobile:userId, token:response.data.token, utype:utype}));
            //Cookies.set('accountDetails', JSON.stringify({token:response.data.loginKey}));
            //window.location.href='/create-account-process';
            window.location.href = "verify-mobile";
            return false;
          } else if (response.data.responseTxt === "InvalidUserId") {
            setMobileVal(true);
            setMobileValMsg("Your user-id or password is invalid.");
            return false;
          } else {
            setMobileVal(true);
            setMobileValMsg("Something wrong somewhere");
            return false;
          }
        })
        .catch((error) => {
          setMobileVal(true);
          setMobileValMsg("" + error);
          return false;
        });
    }
  }

  function onEnter(event) {
    if (event.key === "Enter") {
      submit();
    }
  }

  //   function nameOnly(event) {
  // 	if(!(/[a-z ]/i.test(event.key))) {
  //         event.preventDefault();
  //         return false;
  //     }
  //   }
  //   function numberOnly(event){
  // 	if (!/[0-9]/.test(event.key)) {
  // 		event.preventDefault();
  // 	}
  //   }

  //   function goLocation(url){
  // 	window.location.href=url;
  //   }

  return (
    <>
      <Head>
        <title>
          Learner Login - EaseToLearn India`s Largest Learning Platform
        </title>
        <meta
          name="description"
          content="Online Exam Preparation For Recruitment & Entrance Exam | Online Test Series | Mock Test - EaseToLearn"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>
      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img
                  loading="lazy"
                  alt="ease to learn hero banner ETL"
                  src="/two.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>Login</h1>
                <h5>Login as a Learner</h5>
                <Grid className="frmbx">
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      User Id or Email Id or Mobile Number
                      <TextField
                        onChange={(event) => setUserId(event.target.value)}
                        value={userId}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {mobileVal ? (
                        <FormHelperText>{mobileValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div style={{ paddingTop: 8 }}>
                        Password
                        <TextField
                          type="password"
                          onChange={(event) => setPassword(event.target.value)}
                          value={password}
                          onKeyPress={(event) => {
                            onEnter(event);
                          }}
                          fullWidth
                          variant="outlined"
                        />
                        {newPasswordMsg && newPasswordMsg.length > 0 ? (
                          <FormHelperText>{newPasswordMsg}</FormHelperText>
                        ) : null}
                        <div style={{ textAlign: "right" }}>
                          {waitPassBtn ? (
                            <div style={{ margin: 8 }}>
                              <CircularProgress size={13} color={"inherit"} />{" "}
                              Wait...
                            </div>
                          ) : (
                            <a
                              href="javascript:;"
                              onClick={() => {
                                forgotPassword();
                              }}
                            >
                              Forgot Password?
                            </a>
                          )}
                        </div>
                      </div>
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            Login
                          </a>
                        )}
                      </div>
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        New Learner to ETL?{" "}
                        <a
                          href="javascript:;"
                          onClick={() => {
                            window.location.href = "create-account";
                          }}
                          className="linkhver"
                          style={{ color: "#0000FF" }}
                        >
                          Sign Up
                        </a>
                      </div>
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
        <LoginPop ref={childRefLoginPop} />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
