import React, { useEffect, useState } from "react";
import { useRouter } from "next/router";
import Head from "next/head";

// Components
import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Favicon from "../../client/Favicon";
import Schema from "../../client/Schema";

// CSS
import styles from "./teachers.module.css";

const index = (props) => {
  const router = useRouter();
  const canonicalUrl = (
    `https://easetolearn.com/` + (router.asPath === "/" ? "" : router.asPath)
  ).split("?")[0];

  // States
  const [severityAlert, setSeverityAlert] = useState("error");
  const [showAlert, setShowAlert] = useState(false);
  const [alertMessage, setAlertMessage] = useState("");
  const [playVideoOpt, setPlayVideoOpt] = useState(1);
  const [showHeader, setShowHeader] = useState(false);

  function submit() {
    let emailTxtId = document.getElementById("emailTxtId");
    if (emailTxtId.value == "") {
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter your email");
      emailTxtId.focus();
      return false;
    }
    if (
      emailTxtId.value &&
      emailTxtId.value.length > 0 &&
      !validateEmail(emailTxtId.value)
    ) {
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Email is not valid");
      emailTxtId.focus();
      return false;
    }

    if (emailTxtId.value.length > 0) {
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("email", emailTxtId.value);

      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/website-emails",
          data,
          axiosHeader
        )
        .then((response) => {
          if (response.data.responseTxt === "success") {
            emailTxtId.value = "";
            setSeverityAlert("success");
            setShowAlert(true);
            setAlertMessage("Your message has been sent successfully.");
            return false;
          } else {
            // setFormMessage('Error somewhere, Try after sometime.');
            // return false;
          }
        })
        .catch((error) => {
          // setFormMessage(""+error);
          // return false;
        });
    }
  }

  const schema = {
    breadcrumbs: [
      {
        id: "https://www.easetolearn.com/",
        name: "Home",
      },
    ],
    faq: true,
    website: true,
    review: true,
    video: {
      name: "How does EaseToLearn Work?",
      url: "https://www.youtube.com/watch?v=3lhkCUPAFOY&t=8s",
      datePublished: "2023-05-04",
      uploadDate: "2023-05-04",
      thumbnailUrl: "https://media.easetolearn.com/CompanyLogo.png",
      description: "Fastest method of learning for exams",
    },
  };

  useEffect(() => {
    const handleScroll = (event) => {
      if (window.scrollY > 90) {
        setShowHeader(true);
      } else {
        setShowHeader(false);
      }
    };

    window.addEventListener("scroll", handleScroll);

    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, []);

  return (
    <>
      <Head>
        <title>For Teachers: EaseToLearn</title>
        <Favicon />
        <Schema schema={schema} />
      </Head>
      <main
        className={`${styles.study_room} ${
          showHeader ? "changeHeader" : `${styles.remove_background}`
        }`}
      >
        <Header />
        {/* Banner Section */}
        <section className={styles.study_room_banner}>
          <img
            src="/studyRoomCirlce.svg"
            className={styles.study_room_banner_circle}
            width={571}
            height={833}
            alt="studyRoom circle ETL"
          />
          <img
            src="/studyRoomCircle2.svg"
            className={styles.study_room_banner_circle}
            width={803}
            height={833}
            alt="studyRoom circle ETL"
          />
          <div>
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket}
              width={40}
              height={40}
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket1}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket2}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket3}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket4}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket5}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket6}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket7}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket8}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket9}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket10}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket11}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
          </div>
          <div
            className={`${styles.flex_display} ${styles.study_room_banner_container}`}
          >
            <div
              className={`${styles.flex_display} ${styles.study_room_banner_content}`}
            >
              <h1>My Teaching Room</h1>
              <h2>Enhance your teaching experience with</h2>
              <p>
                Our cutting-edge student & classroom management application.
              </p>

              <a href="/create-account-process">Join Now</a>
            </div>
            <div
              className={`${styles.flex_display} ${styles.study_room_banner_image}`}
            >
              <img
                src="/rocketman.svg"
                width={642}
                height={504}
                alt="ETL Rocket man"
              />
            </div>
          </div>
        </section>
        <img
          src="/bottom1.svg"
          className={styles.study_room_banner_bottom}
          alt="ETL Image"
        />

        {/* Main Content */}
        <section className={styles.mainContent}>
          <h2 className={styles.revolution_heading}>
            Introducing My Teaching Room
          </h2>
          <p className={styles.revolution_para}>
            We are thrilled to introduce our cutting-edge application, designed
            to enhance your teaching experience by facilitating you in managing
            your tuition classes.
          </p>
          <p className={styles.revolution_para}>
            Keeping the ever evolving educational landscape in mind, our app
            allows you to schedule and conduct online classes, doubt clearing
            sessions and interactive assessments.
          </p>
          <p className={styles.revolution_para}>
            The app also offers tools to generate detailed insights of your
            students helping you in providing a timely feedback about their
            performance to them and their parents.
          </p>
        </section>

        {/* Blog */}
        <section className={styles.blogs}>
          <h2>Use the EaseToLearn ecosystem to its fullest!</h2>
          <div className={styles.blogs_cards}>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                />
              </div>
              <h2>Be There For Your Students 24x7</h2>
              <p>
                lorem ipsum dolor sit amet, consectetur adipiscing elit.
                Curabitur tristique felis non odio accumsan laoreet.
              </p>
              <div className={styles.blog_button}>
                <a href="#">Read More</a>
              </div>
            </div>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                />
              </div>
              <h2>Be There For Your Students 24x7</h2>
              <p>
                lorem ipsum dolor sit amet, consectetur adipiscing elit.
                Curabitur tristique felis non odio accumsan laoreet.
              </p>
              <div className={styles.blog_button}>
                <a href="#">Read More</a>
              </div>
            </div>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                />
              </div>
              <h2>Be There For Your Students 24x7</h2>
              <p>
                lorem ipsum dolor sit amet, consectetur adipiscing elit.
                Curabitur tristique felis non odio accumsan laoreet.
              </p>
              <div className={styles.blog_button}>
                <a href="#">Read More</a>
              </div>
            </div>
          </div>
        </section>

        <section>
          <h2 className={styles.revolution_heading}>
            Introducing My Teaching Room
          </h2>
          <div className={styles.teaching_room}>
            <div className={styles.teaching_room_card}>
              <h3>Efficient & Time Saving</h3>
              <p>
                Streamline your assessment & feedback processes. Focus more on
                teaching and less on administrative tasks.
              </p>
            </div>
            <div className={styles.teaching_room_card}>
              <h3>Enhanced Experience</h3>
              <p>
              Encourage active student participation, foster collaboration and discussion. Enhance the overall learning experience.
              </p>
            </div>
            <div className={styles.teaching_room_card}>
              <h3>Personalized Learning</h3>
              <p>
              Tailor your teaching methods based on individual student performance & feedback and ensure that each student reaches their full potential.
              </p>
            </div>
            <div className={styles.teaching_room_card}>
              <h3>Professional Development</h3>
              <p>
              Access our resources to enhance your online teaching skills and stay updated with the latest educational trends & pedagogical approaches. 
              </p>
            </div>
            <div className={styles.teaching_room_card}>
              <h3>Transparency</h3>
              <p>
              Maintain transparency with students & parents by addressing queries & providing updates  in real time using our in-app messaging feature.
              </p>
            </div>
            <div className={styles.teaching_room_card}>
              <h3>Secure & Reliable</h3>
              <p>
              Our application employs advanced security measures to protect sensitive information, ensuring a safe online learning environment.
              </p>
            </div>
          </div>
        </section>

        {/* Email */}
        <section className="mycontainer" style={{ marginTop: 60 }}>
          <div className="subscribebox">
            <h4 className="color-dark">
              Subscribe to our email
              <br />
              for latest news and updates
            </h4>
            <form className="submitbox">
              <input
                type="email"
                id="emailTxtId"
                placeholder="Enter your email address"
              />
              <button
                type="button"
                onClick={() => {
                  submit();
                }}
                className="btn"
              >
                Submit
              </button>
            </form>
          </div>

          <div className="bottommin-res"></div>
        </section>
        <Footer />
      </main>
    </>
  );
};

export default index;
