import React, { useState, useEffect } from "react";
import axios from "axios";
import Head from "next/head";
import Cookies from "js-cookie";
import OtpInput from "react-otp-input";

import Header from "../components/Header";
import Footer from "../components/Footer";

import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import CircularProgress from "@mui/material/CircularProgress";
import FormHelperText from "@mui/material/FormHelperText";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  let resetTokenObj = {};
  if (Cookies.get("resetPasswordToken")) {
    resetTokenObj = JSON.parse(Cookies.get("resetPasswordToken"));
  }
  const classes = useStyles();
  const [waitBtn, setWaitBtn] = useState(false);

  const [firstName, setFirstName] = useState("");
  const [lastName, setLastName] = useState("");
  const [mobileNumber, setMobileNumber] = useState("");
  const [token, setToken] = useState("");
  const [utype, setUtype] = useState("Learner");

  const [otpNumber, setOtpNumber] = useState("");
  const [otpVal, setOtpVal] = useState(false);
  const [otpValMsg, setOtpValMsg] = useState("Enter your OTP number");

  const [resendLoading, setResendLoading] = useState(false);
  const [resendValidationMsg, setResendValidationMsg] = useState("");

  ///alert("newaccount: "+newaccount)

  useEffect(() => {
    if (!newaccount && !resetTokenObj) {
      window.location.href = "/create-account";
    } else if (resetTokenObj && resetTokenObj.resetPasswordToken) {
      setToken(resetTokenObj.resetPasswordToken);
    } else if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setUtype(obj.utype);
      setToken(obj.token);
    }
  }, [newaccount]);

  function submit() {
    if (!otpNumber) {
      setOtpVal(true);
    } else {
      setOtpVal(false);
    }

    if (otpNumber && token && token.length > 2) {
      setWaitBtn(true);

      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("token", token);
      data.append("otpNumber", otpNumber);

      if (utype === "Learner") {
        data.append("studentName", firstName + " " + lastName);
        data.append("mobile", mobileNumber);
      }

      let apiURL = "/verifyotp";
      if (resetTokenObj && resetTokenObj.resetPasswordToken) {
        apiURL = "/web-verify-forgotpassword";
      }
      axios
        .post(process.env.NEXT_PUBLIC_API_URL + apiURL, data, axiosHeader)
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "OK") {
            ///alert('OTP Page: '+response.data.token);
            if (resetTokenObj && resetTokenObj.resetPasswordToken) {
              Cookies.set(
                "accountDetails",
                JSON.stringify({ token: resetTokenObj.loginKey })
              );
              window.location.href = "/create-account-process";
            } else {
              Cookies.set(
                "newaccount",
                JSON.stringify({
                  firstName: firstName,
                  lastName: lastName,
                  mobile: mobileNumber,
                  utype: utype,
                })
              );
              window.location.href = "enter-email";
            }
            return false;
          } else if (response.data.responseTxt === "InvalidOTP") {
            setOtpVal(true);
            setOtpValMsg("Invalid OTP");
            return false;
          } else if (response.data.responseTxt === "InvalidToken") {
            setOtpVal(true);
            setOtpValMsg("Invalid Token");
            return false;
          } else {
            setOtpVal(true);
            setOtpValMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setOtpVal(true);
          setOtpValMsg("" + error);
          return false;
        });
    }
  }

  function resendOtpApi() {
    try {
      setResendLoading(true);
      const formData = new FormData();
      formData.append("token", token);
      formData.append("mobile", mobileNumber);
      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/resend-otpmobilenumber",
          formData
        )
        .then((response) => {
          setResendLoading(false);
          if (response.data != null && response.data.responseTxt == "OK") {
            setResendValidationMsg("");
            setResendValidationMsg("OTP sent again");
          } else {
            setResendValidationMsg("Something went wrong, Try after sometime.");
          }
          ////console.log("AAA Response >> " + response.data);
        })
        .catch((error) => console.error(error));
    } catch (error) {
      console.error(error.response.data);
    }
  }

  function numberOnly(event) {
    if (!/[0-9]/.test(event.key)) {
      event.preventDefault();
    }
  }

  function maskNumber(number) {
    return number.substring(0, 2) + "*****" + number.substring(7, 10);
  }

  return (
    <>
      <Head>
        <title>Online Tests for Recruitment &amp; Entrance Exams</title>
        <meta
          name="description"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img alt="ease to learn hero banner ETL" src="/two.webp" />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>
                  {resetTokenObj && resetTokenObj.resetPasswordToken ? (
                    <>Enter OTP</>
                  ) : (
                    <>Verify your mobile</>
                  )}
                </h1>
                <Grid className="frmbx">
                  <Grid item md={12} sm={12} xs={12}>
                    <div className="paybtnbox">
                      <span className="otp">
                        {resetTokenObj && resetTokenObj.resetPasswordToken ? (
                          <>
                            We have sent an OTP to your mobile number & email id
                          </>
                        ) : (
                          <>
                            We have sent an OTP to your mobile number through
                            SMS
                          </>
                        )}
                      </span>
                      <br />
                      {mobileNumber ? maskNumber(mobileNumber) : null}
                    </div>
                  </Grid>
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      <span className="enter_otp_label">Enter OTP</span>
                      <OtpInput
                        value={otpNumber}
                        onChange={setOtpNumber}
                        numInputs={6}
                        renderSeparator={<span>-</span>}
                        containerStyle="otp_container"
                        inputStyle="otp_inputStyle"
                        inputType="number"
                        renderInput={(props) => <input {...props} />}
                      />
                      {/* <TextField
                        onChange={(event) => setOtpNumber(event.target.value)}
                        value={otpNumber}
                        onKeyPress={(event) => {
                          numberOnly(event);
                        }}
                        fullWidth
                        variant="outlined"
                        inputProps={{ maxLength: 6 }}
                      /> */}
                      {otpVal ? (
                        <FormHelperText>{otpValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            SUBMIT OTP
                          </a>
                        )}
                      </div>
                    </Grid>
                    {!resetTokenObj ? (
                      <Grid item md={12} sm={12} xs={12}>
                        <div className="paybtnbox">
                          {resendLoading ? (
                            <div style={{ textAlign: "center" }}>
                              <CircularProgress color="secondary" />
                              <br />
                              WAIT...
                            </div>
                          ) : resendValidationMsg &&
                            resendValidationMsg.indexOf("sent") > -1 ? (
                            <span
                              style={{ color: "#008000", fontWeight: "bold" }}
                            >
                              {resendValidationMsg}
                            </span>
                          ) : resendValidationMsg &&
                            resendValidationMsg.indexOf("wrong") > -1 ? (
                            <span
                              style={{ color: "#FF0000", fontWeight: "bold" }}
                            >
                              {resendValidationMsg}
                            </span>
                          ) : (
                            <div>
                              Did not receive OTP?{" "}
                              <a
                                href="javascript:;"
                                onClick={() => {
                                  resendOtpApi();
                                }}
                              >
                                Resend OTP
                              </a>
                            </div>
                          )}
                          <br />
                          <br />
                          <br />
                          <a href="create-account">
                            Back to change mobile number
                          </a>
                        </div>
                      </Grid>
                    ) : null}
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
